@@ -10,24 +10,28 @@ from datetime import datetime, date, time, timedelta
 from decimal import Decimal
 
 import pytest
+import os
 import sys
 
 import re
 from six import BytesIO
 
 from franz.openrdf.connect import ag_connect
+from franz.openrdf.exceptions import RequestError
 from franz.openrdf.model import Literal, Statement
 from franz.openrdf.query.query import QueryLanguage
 from franz.openrdf.rio.rdfformat import RDFFormat
 from franz.openrdf.rio.tupleformat import TupleFormat
 from franz.openrdf.sail import AllegroGraphServer
 from franz.openrdf.tests.tz import MockTimezone
+from franz.openrdf.util.contexts import output_to
 from franz.openrdf.vocabulary import XMLSchema
 
 from .tests import AG_HOST, AG_PORT, AG_PROXY, CATALOG, STORE, USER, PASSWORD
 
 common_args = dict(
-    host=AG_HOST, port=AG_PORT, catalog=CATALOG, user=USER, password=PASSWORD, proxy=AG_PROXY
+    host=AG_HOST, port=AG_PORT, catalog=CATALOG,
+    user=USER, password=PASSWORD, proxy=AG_PROXY
 )
 
 
@@ -69,41 +73,52 @@ def test_ag_connect_session(repo_name):
         assert conn.is_session_active
 
 
-def test_server_all_data_in_host():
+def test_server_all_data_in_host(clean_env):
     server = AllegroGraphServer('https://somehost:4321/and/then/some')
     assert server.url == 'https://somehost:4321/and/then/some'
 
 
-def test_server_all_defaults():
+def test_server_all_defaults(clean_env):
     server = AllegroGraphServer('somehost')
     assert server.url == 'http://somehost:10035'
 
 
-def test_server_protocol_as_arg():
+def test_server_protocol_as_arg(clean_env):
     server = AllegroGraphServer('somehost', protocol='https')
     assert server.url == 'https://somehost:10036'
 
 
-def test_server_override_protocol():
+def test_server_override_protocol(clean_env):
     server = AllegroGraphServer('http://somehost', protocol='https')
     assert server.url == 'https://somehost:10036'
 
 
-def test_server_port_as_arg():
+def test_server_port_as_arg(clean_env):
     server = AllegroGraphServer('somehost', port=4321)
     assert server.url == 'http://somehost:4321'
 
 
-def test_server_override_port():
+def test_server_override_port(clean_env):
     server = AllegroGraphServer('somehost:1234', port=4321)
     assert server.url == 'http://somehost:4321'
 
 
-def test_server_https_if_cainfo():
+def test_server_https_if_cainfo(clean_env):
     server = AllegroGraphServer('somehost', cainfo='/path/to/ca/bundle')
     assert server.url == 'https://somehost:10036'
 
 
+def test_server_url_in_env(clean_env):
+    clean_env['AGRAPH_HOST'] = 'somehost'
+    clean_env['AGRAPH_PORT'] = 12345
+    clean_env['AGRAPH_USER'] = 'luser'
+    clean_env['AGRAPH_PASSWORD'] = '1234'
+    server = AllegroGraphServer()
+    assert server.url == 'http://somehost:12345'
+    assert server._client.user == 'luser'
+    assert server._client.password == '1234'
+
+
 @pytest.mark.parametrize("filename, expected_format, expected_compression", [
     ("somefile.rdf", "RDF/XML", None),
     ("somefile.rdfs", "RDF/XML", None),
@@ -400,3 +415,48 @@ def test_time_tz_roundtrip(conn, s, p):
     conn.addTriple(s, p, t)
     actual = conn.getStatements().asList()[0].getObject()
     assert actual == t
+
+
+def test_invalid_query(conn):
+    query = conn.prepareTupleQuery(QueryLanguage.SPARQL,
+                                   '"; DROP TABLE students;')
+    with open(os.devnull, 'w') as out:
+        with pytest.raises(RequestError):
+            query.evaluate(output=out)
+
+
+def test_default_rdf_format(conn):
+    out = BytesIO()
+    query = conn.prepareGraphQuery(QueryLanguage.SPARQL,"""
+        CONSTRUCT { <ex://s> <ex://p> <ex://o> } WHERE {}""")
+    query.evaluate(output=out)
+    assert out.getvalue()
+
+
+def test_default_tuple_format(conn):
+    out = BytesIO()
+    query = conn.prepareTupleQuery(QueryLanguage.SPARQL,"""
+        SELECT ?x { BIND(42 as ?x) }""")
+    query.evaluate(output=out)
+    assert out.getvalue()
+
+
+def test_output_to_true(capfd):
+    with output_to(True) as f:
+        f.write(b'test')
+    out, err = capfd.readouterr()
+    assert out == 'test'
+
+
+def test_output_to_stderr(capfd):
+    with output_to(2) as f:
+        f.write(b'test')
+    out, err = capfd.readouterr()
+    assert err == 'test'
+
+
+def test_export_to_true(capfd, conn, s, p, o):
+    conn.add(s, p, o)
+    conn.getStatements(output=True)
+    out, err = capfd.readouterr()
+    assert out.strip() == "<ex://s> <ex://p> <ex://o> ."
